@@ -1,6 +1,6 @@
 from gym.envs.registration import register
 
 register(
-    id='lsm_params_env',
+    id='lsm_params_env-v0',
     entry_point='lsm_params_env.envs:ParamsEnv'
 )
\ No newline at end of file
